@@ -13,7 +13,6 @@
 #    under the License.
 
 import operator
-import six
 
 import pecan
 from pecan import rest
@@ -93,8 +92,7 @@ class ControllerMetaclass(type):
                                                        cls_dict)
 
 
-@six.add_metaclass(ControllerMetaclass)
-class Controller(rest.RestController):
+class Controller(rest.RestController, metaclass=ControllerMetaclass):
     """Base Rest Controller"""
 
     @pecan.expose('json')
@@ -160,7 +158,7 @@ class Controller(rest.RestController):
         @min_ver: string representing minimum version
         @max_ver: optional string representing maximum version
         @raises: ApiVersionsIntersect if an version overlap is found between
-            method versions.
+        method versions.
         """
 
         def decorator(f):
