@@ -21,10 +21,19 @@ LOG = logging.getLogger(__name__)
 
 
 class RamFilter(filters.BaseHostFilter):
-    """Filter the containers by memory request"""
+    """DEPRECATED: Filter the containers by memory request"""
 
     run_filter_once_per_request = True
 
+    def __init__(self):
+        super(RamFilter, self).__init__()
+        LOG.warning('The RamFilter is deprecated since the 7.0.0 '
+                    'Wallaby release. MEMORY_MB filtering is performed '
+                    'natively using the Placement service when using the '
+                    'filter_scheduler driver. Operators should define ram '
+                    'allocation ratios either per host in the zun.conf '
+                    'or via the placement API.')
+
     def host_passes(self, host_state, container, extra_spec):
         if not container.memory:
             return True
