@@ -11,8 +11,8 @@
 #    limitations under the License.
 
 import collections
-import mock
-import six
+from unittest import mock
+
 from webob import exc
 
 from zun.api.controllers import base
@@ -85,8 +85,8 @@ class TestAPIBase(test_base.BaseTestCase):
         ])
         actual_value = collections.OrderedDict(
             sorted(test_api.as_dict().items()))
-        self.assertEqual(six.text_type(expected_value),
-                         six.text_type(actual_value))
+        self.assertEqual(str(expected_value),
+                         str(actual_value))
 
 
 class TestVersion(test_base.TestCase):
@@ -394,7 +394,7 @@ class TestController(test_base.TestCase):
                 return 'API1_1.0_1.1'
 
             @base.Controller.api_version('1.2', '1.3')  # noqa
-            def testapi1(self):
+            def testapi1(self):  # noqa
                 return 'API1_1.2_1.3'
 
             @base.Controller.api_version('2.1', '2.2')
@@ -402,7 +402,7 @@ class TestController(test_base.TestCase):
                 return 'API2_2.1_2.2'
 
             @base.Controller.api_version('1.0', '2.0')  # noqa
-            def testapi2(self):
+            def testapi2(self):  # noqa
                 return 'API2_1.0_2.0'
 
         controller = MyController()
@@ -445,7 +445,7 @@ class TestController(test_base.TestCase):
                 return 'API1_1.0_1.1'
 
             @base.Controller.api_version('1.2', '1.3')  # noqa
-            def testapi1(self):
+            def testapi1(self):  # noqa
                 return 'API1_1.2_1.3'
 
         controller = MyController()
@@ -467,7 +467,7 @@ class TestController(test_base.TestCase):
                 return 'API1_1.0_1.1'
 
             @base.Controller.api_version('1.3', '1.4')  # noqa
-            def testapi1(self):
+            def testapi1(self):  # noqa
                 return 'API1_1.3_1.4'
 
         controller = MyController()
@@ -475,5 +475,5 @@ class TestController(test_base.TestCase):
                                                       "", "1.2")
         controller.request = mock_pecan_request
 
-        self.assertRaises(exc.HTTPNotAcceptable,
-                          controller.__getattribute__, 'testapi1')
+        method = controller.__getattribute__('testapi1')
+        self.assertRaises(exc.HTTPNotAcceptable, method)
