@@ -10,7 +10,8 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import mock
+from unittest import mock
+
 from oslo_config import cfg
 
 from zun.api import servicegroup
