@@ -16,7 +16,8 @@ from zun.common.utils import check_container_id
 from zun.container import driver
 
 
-class FakeDriver(driver.ContainerDriver):
+class FakeDriver(driver.BaseDriver, driver.ContainerDriver,
+                 driver.CapsuleDriver):
     """Fake driver for testing."""
 
     def __init__(self):
@@ -105,9 +106,6 @@ class FakeDriver(driver.ContainerDriver):
     def resize(self, context, container, height, weight):
         pass
 
-    def get_addresses(self, context, container):
-        pass
-
     @check_container_id
     def update(self, context, container):
         pass
